# coding: utf-8

"""
    AssistedInstall

    Assisted installation  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class ClusterValidationId(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    allowed enum values
    """
    MACHINE_CIDR_DEFINED = "machine-cidr-defined"
    CLUSTER_CIDR_DEFINED = "cluster-cidr-defined"
    SERVICE_CIDR_DEFINED = "service-cidr-defined"
    NO_CIDRS_OVERLAPPING = "no-cidrs-overlapping"
    NETWORKS_SAME_ADDRESS_FAMILIES = "networks-same-address-families"
    NETWORK_PREFIX_VALID = "network-prefix-valid"
    MACHINE_CIDR_EQUALS_TO_CALCULATED_CIDR = "machine-cidr-equals-to-calculated-cidr"
    API_VIPS_DEFINED = "api-vips-defined"
    API_VIPS_VALID = "api-vips-valid"
    INGRESS_VIPS_DEFINED = "ingress-vips-defined"
    INGRESS_VIPS_VALID = "ingress-vips-valid"
    ALL_HOSTS_ARE_READY_TO_INSTALL = "all-hosts-are-ready-to-install"
    SUFFICIENT_MASTERS_COUNT = "sufficient-masters-count"
    DNS_DOMAIN_DEFINED = "dns-domain-defined"
    PULL_SECRET_SET = "pull-secret-set"
    NTP_SERVER_CONFIGURED = "ntp-server-configured"
    LSO_REQUIREMENTS_SATISFIED = "lso-requirements-satisfied"
    OCS_REQUIREMENTS_SATISFIED = "ocs-requirements-satisfied"
    ODF_REQUIREMENTS_SATISFIED = "odf-requirements-satisfied"
    CNV_REQUIREMENTS_SATISFIED = "cnv-requirements-satisfied"
    LVM_REQUIREMENTS_SATISFIED = "lvm-requirements-satisfied"
    MCE_REQUIREMENTS_SATISFIED = "mce-requirements-satisfied"
    MTV_REQUIREMENTS_SATISFIED = "mtv-requirements-satisfied"
    OSC_REQUIREMENTS_SATISFIED = "osc-requirements-satisfied"
    NETWORK_TYPE_VALID = "network-type-valid"
    PLATFORM_REQUIREMENTS_SATISFIED = "platform-requirements-satisfied"
    NODE_FEATURE_DISCOVERY_REQUIREMENTS_SATISFIED = "node-feature-discovery-requirements-satisfied"
    NVIDIA_GPU_REQUIREMENTS_SATISFIED = "nvidia-gpu-requirements-satisfied"
    PIPELINES_REQUIREMENTS_SATISFIED = "pipelines-requirements-satisfied"
    SERVICEMESH_REQUIREMENTS_SATISFIED = "servicemesh-requirements-satisfied"
    SERVERLESS_REQUIREMENTS_SATISFIED = "serverless-requirements-satisfied"
    OPENSHIFT_AI_REQUIREMENTS_SATISFIED = "openshift-ai-requirements-satisfied"
    OPENSHIFT_AI_GPU_REQUIREMENTS_SATISFIED = "openshift-ai-gpu-requirements-satisfied"
    AUTHORINO_REQUIREMENTS_SATISFIED = "authorino-requirements-satisfied"
    NMSTATE_REQUIREMENTS_SATISFIED = "nmstate-requirements-satisfied"
    AMD_GPU_REQUIREMENTS_SATISFIED = "amd-gpu-requirements-satisfied"
    KMM_REQUIREMENTS_SATISFIED = "kmm-requirements-satisfied"
    NODE_HEALTHCHECK_REQUIREMENTS_SATISFIED = "node-healthcheck-requirements-satisfied"
    SELF_NODE_REMEDIATION_REQUIREMENTS_SATISFIED = "self-node-remediation-requirements-satisfied"
    FENCE_AGENTS_REMEDIATION_REQUIREMENTS_SATISFIED = "fence-agents-remediation-requirements-satisfied"
    NODE_MAINTENANCE_REQUIREMENTS_SATISFIED = "node-maintenance-requirements-satisfied"
    KUBE_DESCHEDULER_REQUIREMENTS_SATISFIED = "kube-descheduler-requirements-satisfied"
    CLUSTER_OBSERVABILITY_REQUIREMENTS_SATISFIED = "cluster-observability-requirements-satisfied"
    NUMA_RESOURCES_REQUIREMENTS_SATISFIED = "numa-resources-requirements-satisfied"
    OADP_REQUIREMENTS_SATISFIED = "oadp-requirements-satisfied"
    METALLB_REQUIREMENTS_SATISFIED = "metallb-requirements-satisfied"

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
    }

    attribute_map = {
    }

    def __init__(self):  # noqa: E501
        """ClusterValidationId - a model defined in Swagger"""  # noqa: E501
        self.discriminator = None

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ClusterValidationId, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ClusterValidationId):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
